@@ -1,11 +1,8 @@
-import ctypes
 import socket
 import sys
 from typing import Optional, Tuple, Union
 
-from . import ffi, util
-
-__version__ = "0.2.0"
+__version__ = "0.2.1"
 
 __all__ = ["get_peer_uid_gid"]
 
@@ -14,60 +11,28 @@ if sys.platform.startswith(("linux", "openbsd", "netbsd")):
 
     __all__.append("ucred")
 
-
-if sys.platform.startswith(("freebsd", "dragonfly", "darwin")):
-    from . import xucred  # noqa: F401
-
-    __all__.append("xucred")
-
-
-if sys.platform.startswith(("solaris", "illumos")):
-    from . import peerucred  # noqa: F401
-
-    __all__.append("peerucred")
-
-
-if sys.platform.startswith(("openbsd", "netbsd", "freebsd", "dragonfly", "darwin")):
-    libc = ffi.load_libc()
-
-    libc.getpeereid.argtypes = (
-        ctypes.c_int,
-        ctypes.POINTER(ffi.uid_t),
-        ctypes.POINTER(ffi.gid_t),
-    )
-    libc.getpeereid.restype = ctypes.c_int
-
-    def getpeereid(sock: Union[socket.socket, int]) -> Tuple[int, int]:
-        uid = ffi.uid_t()
-        gid = ffi.gid_t()
-
-        if not isinstance(sock, int):
-            sock = sock.fileno()
-
-        res = libc.getpeereid(sock, ctypes.pointer(uid), ctypes.pointer(gid))
-        if res != 0:
-            raise util.build_oserror(ctypes.get_errno())
-
-        return uid.value, gid.value
-
-    __all__.append("getpeereid")
-
-    def get_peer_uid_gid(sock: Union[socket.socket, int]) -> Tuple[int, int]:
-        return getpeereid(sock)
-
-
-elif sys.platform.startswith("linux"):
-
     def get_peer_uid_gid(sock: Union[socket.socket, int]) -> Tuple[int, int]:
         cred = ucred.get_ucred(sock)
         return cred.uid, cred.gid
 
 
-elif sys.platform.startswith(("solaris", "illumos")):
+elif sys.platform.startswith(("freebsd", "dragonfly", "darwin")):
+    from . import xucred  # noqa: F401
+
+    __all__.append("xucred")
 
     def get_peer_uid_gid(sock: Union[socket.socket, int]) -> Tuple[int, int]:
-        cred = peerucred.getpeerucred(sock)
-        return cred.euid, cred.egid
+        cred = xucred.get_xucred(sock)
+        return cred.uid, cred.gid
+
+
+elif sys.platform.startswith(("solaris", "illumos")):
+    from . import peerucred  # noqa: F401
+
+    __all__.append("peerucred")
+
+    def get_peer_uid_gid(sock: Union[socket.socket, int]) -> Tuple[int, int]:
+        return peerucred._get_peer_uid_gid(sock)  # pylint: disable=protected-access
 
 
 else:
@@ -94,8 +59,7 @@ elif sys.platform.startswith("freebsd"):
 elif sys.platform.startswith(("solaris", "illumos")):
 
     def get_peer_pid_uid_gid(sock: Union[socket.socket, int]) -> Tuple[Optional[int], int, int]:
-        cred = peerucred.getpeerucred(sock)
-        return cred.pid, cred.euid, cred.egid
+        return peerucred._get_peer_pid_uid_gid(sock)  # pylint: disable=protected-access
 
     __all__.append("get_peer_pid_uid_gid")
 
@@ -114,7 +78,7 @@ Returns:
 
 if "get_peer_pid_uid_gid" in locals():
     get_peer_pid_uid_gid.__doc__ = """
-Try to get the PID, UID and GID of the peer of the given socket.
+Try to get the PID, UID, and GID of the peer of the given socket.
 
 Args:
     sock: The socket for which to obtain credentials.
