@@ -9,7 +9,6 @@ from typing import List, Optional, Union
 from . import constants, ffi, util
 
 if sys.platform.startswith("freebsd"):
-    _HAS_PID = True
 
     class _XcuredCr(ctypes.Union):  # pylint: disable=too-few-public-methods
         _fields_ = [
@@ -18,10 +17,6 @@ if sys.platform.startswith("freebsd"):
         ]
 
 
-else:
-    _HAS_PID = False
-
-
 class _Xucred(ctypes.Structure):  # pylint: disable=too-few-public-methods
     if sys.platform.startswith("freebsd"):
         _anonymous_ = ("_cr",)
@@ -59,12 +54,9 @@ class _Xucred(ctypes.Structure):  # pylint: disable=too-few-public-methods
 
         groups = list(self.cr_groups[: self.cr_ngroups])
 
-        kwargs = {"uid": self.cr_uid, "gid": groups[0], "groups": groups}
-
-        if _HAS_PID:
-            kwargs["pid"] = self.cr_pid if self.cr_pid > 0 else None
-
-        return Xucred(**kwargs)
+        return Xucred(
+            uid=self.cr_uid, gid=groups[0], groups=groups, pid=(getattr(self, "cr_pid", 0) or None)
+        )
 
 
 @dataclasses.dataclass
@@ -74,14 +66,15 @@ class Xucred:
 
     groups: List[int]
 
-    if _HAS_PID:
-        pid: Optional[int]
+    pid: Optional[int]
 
 
 def get_xucred(sock: Union[socket.socket, int]) -> Xucred:
     with util.with_socket_or_fd(sock) as sock_obj:
         buf = sock_obj.getsockopt(
-            0, socket.LOCAL_PEERCRED, ctypes.sizeof(_Xucred),  # pylint: disable=no-member
+            0,
+            socket.LOCAL_PEERCRED,  # pylint: disable=no-member
+            ctypes.sizeof(_Xucred),
         )
 
     return _Xucred.from_buffer_copy(buf).convert()
